@@ -189,6 +189,14 @@ bool WebEnginePage::acceptNavigationRequest(const QUrl& url, NavigationType type
 {
     if (m_urlLoadedByPart != url) {
         m_urlLoadedByPart = QUrl();
+        
+        //Don't open local files using WebEnginePart except if configured to do so by the user. For example
+        //for example, this ensures that the "Home" link in the introduction page is opened in Dolphin part 
+        //(or whichever part the user has chosen to open directories instead of WebEnginePart
+        if (url.isLocalFile()) {
+            emit m_part->browserExtension()->openUrlRequest(url);
+            return false;
+        }
     }
 //     qCDebug(WEBENGINEPART_LOG) << url << "type=" << type;
     QUrl reqUrl(url);
@@ -284,7 +292,7 @@ static int errorCodeFromReply(QNetworkReply* reply)
 
     switch (reply->error()) {
         case QNetworkReply::ConnectionRefusedError:
-            return KIO::ERR_COULD_NOT_CONNECT;
+            return KIO::ERR_CANNOT_CONNECT;
         case QNetworkReply::HostNotFoundError:
             return KIO::ERR_UNKNOWN_HOST;
         case QNetworkReply::TimeoutError:
@@ -300,7 +308,7 @@ static int errorCodeFromReply(QNetworkReply* reply)
         case QNetworkReply::ContentNotFoundError:
             return KIO::ERR_NO_CONTENT;
         case QNetworkReply::AuthenticationRequiredError:
-            return KIO::ERR_COULD_NOT_AUTHENTICATE;
+            return KIO::ERR_CANNOT_AUTHENTICATE;
         case QNetworkReply::ProtocolUnknownError:
             return KIO::ERR_UNSUPPORTED_PROTOCOL;
         case QNetworkReply::ProtocolInvalidOperationError:
